@@ -4,7 +4,7 @@
 
 ;; Filename: coterm.el
 ;; Author: jakanakaevangeli <jakanakaevangeli@chiru.no>
-;; Version: 1.3
+;; Version: 1.4
 ;; Keywords: processes
 ;; Package-Requires: ((emacs "26.1"))
 ;; URL: https://repo.or.cz/emacs-coterm.git
@@ -461,11 +461,11 @@ active if these status prompt erasures are detected."
       (forward-line -1)
       (prog1 (looking-at
               (concat "\\(?:.*\n\\)?"
-                      "\\(?:(Paused) \\)?"
+                      (regexp-opt '("(Paused) " "(Buffering) " "(...) " ""))
                       "\\(?:[AV]\\|AV\\): "
-                      "[0-9][0-9]:[0-9][0-9]:[0-9][0-9] / "
-                      "[0-9][0-9]:[0-9][0-9]:[0-9][0-9] "
-                      "([0-9]?[0-9]%).*"
+                      "-?[0-9][0-9]:[0-9][0-9]:[0-9][0-9] / "
+                      "-?[0-9][0-9]:[0-9][0-9]:[0-9][0-9] "
+                      "([0-9]?[0-9]?[0-9]%).*"
                       "\\(?:"
                       "\n\\[-*\\+-*\\]"
                       "\\)?"
@@ -1025,9 +1025,10 @@ buffer and the scrolling region must cover the whole screen."
                                    ansi-color-context)))
                    (?8 (ins) ;; Restore cursor (terminfo: rc)
                        (when-let ((cursor coterm--t-saved-cursor))
-                         (setq coterm--t-row (max (car cursor) (1- coterm--t-height)))
+                         (setq coterm--t-saved-cursor nil)
+                         (setq coterm--t-row (min (car cursor) (1- coterm--t-height)))
                          (setq cursor (cdr cursor))
-                         (setq coterm--t-col (max (car cursor) (1- coterm--t-width)))
+                         (setq coterm--t-col (min (car cursor) (1- coterm--t-width)))
                          (setq cursor (cdr cursor))
                          (setq ansi-color-context-region (car cursor))
                          (setq ansi-color-context (cadr cursor))
@@ -1055,7 +1056,7 @@ buffer and the scrolling region must cover the whole screen."
                                                 (split-string ctl-params ";")))
                        (ins)
                        (pcase char
-                         (?H ;; cursor motion (terminfo: cup,home)
+                         ((or ?H ?f) ;; cursor motion (terminfo: cup,home)
                           (setq coterm--t-row
                                 (1- (max 1 (min (car-or-1) coterm--t-height))))
                           (setq coterm--t-col
@@ -1105,9 +1106,10 @@ buffer and the scrolling region must cover the whole screen."
                           (coterm--t-delete-region coterm--t-row 0
                                                    coterm--t-row coterm--t-col)
                           (coterm--t-open-space proc-filt process 0 coterm--t-col))
-                         (?K (coterm--t-delete-region
-                              coterm--t-row coterm--t-col
-                              coterm--t-row coterm--t-width))
+                         (?K (when (< coterm--t-col coterm--t-width)
+                               (coterm--t-delete-region
+                                coterm--t-row coterm--t-col
+                                coterm--t-row coterm--t-width)))
                          (?L ;; \E[L - insert lines (terminfo: il, il1)
                           (when (<= coterm--t-scroll-beg coterm--t-row
                                     (1- coterm--t-scroll-end))
